@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2018 the original author or authors.
+ * Copyright 2001-2021 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -43,12 +43,17 @@ public final class ArgumentToString {
             buffer.append("'");
         } else if (value.getClass().isArray()) {
             buffer.append("[");
-            for (int i = 0; i < Array.getLength(value); i++) {
+            int length = Array.getLength(value);
+            int printedLength = Math.min(100, length);
+            for (int i = 0; i < printedLength; i++) {
                 if (i > 0) {
                     buffer.append(", ");
                 }
                 appendArgument(Array.get(value, i), buffer);
             }
+            if(length > printedLength) {
+                buffer.append("... (length=").append(length).append(")");
+            }
             buffer.append("]");
         } else if (PrimitiveUtils.isPrimitiveWrapper(value.getClass())) {
             buffer.append(value)
