@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2020 the original author or authors.
+ * Copyright 2001-2021 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,12 +15,19 @@
  */
 package org.easymock.internal;
 
-import org.easymock.*;
+import org.easymock.ConstructorArgs;
+import org.easymock.EasyMock;
+import org.easymock.IAnswer;
+import org.easymock.IExpectationSetters;
+import org.easymock.IMocksControl;
+import org.easymock.MockType;
 
 import java.io.Serializable;
 import java.lang.reflect.InvocationHandler;
 import java.lang.reflect.Method;
 import java.lang.reflect.Proxy;
+import java.util.Arrays;
+import java.util.Set;
 
 /**
  * @author OFFIS, Tammo Freese
@@ -84,8 +91,10 @@ public class MocksControl implements IMocksControl, IExpectationSetters<Object>,
         if (toMock == null) {
             throw new NullPointerException("Can't mock 'null'");
         }
+        // If we have mockedMethods, it means it's a partial mock. So it shouldn't be an interface that is mocked
+        // unless the interface has default methods and that it's some of these methods that are in mockedMethods
         if (toMock.isInterface() && mockedMethods != null) {
-            throw new IllegalArgumentException("Partial mocking doesn't make sense for interface");
+            checkInterfaceHasDefaultMethodAndIsMockingOnlyThem(toMock, mockedMethods);
         }
 
         try {
@@ -111,6 +120,17 @@ public class MocksControl implements IMocksControl, IExpectationSetters<Object>,
         }
     }
 
+    private <T> void checkInterfaceHasDefaultMethodAndIsMockingOnlyThem(Class<T> toMock, Method[] mockedMethods) {
+        Set<Method> defaultMethods = ReflectionUtils.getDefaultMethods(toMock);
+        if(defaultMethods.isEmpty()) {
+            throw new IllegalArgumentException("Partial mocking doesn't make sense for interface (" + toMock +  ") without default defaultMethods");
+        }
+        if(!defaultMethods.containsAll(Arrays.asList(mockedMethods))) {
+            throw new IllegalArgumentException("Mocking non-default method (one of " + Arrays.toString(mockedMethods)
+                + ") of an interface (" + toMock +  ")  doesn't make sense.");
+        }
+    }
+
     public static IProxyFactory getProxyFactory(Object o) {
         return Proxy.isProxyClass(o.getClass())
                 ? interfaceProxyFactory
@@ -120,7 +140,7 @@ public class MocksControl implements IMocksControl, IExpectationSetters<Object>,
     private static IProxyFactory getClassProxyFactory() {
         String classMockingDisabled = EasyMockProperties.getInstance().getProperty(
                 EasyMock.DISABLE_CLASS_MOCKING);
-        if (Boolean.valueOf(classMockingDisabled)) {
+        if (Boolean.parseBoolean(classMockingDisabled)) {
             throw new IllegalArgumentException("Class mocking is currently disabled. Change "
                     + EasyMock.DISABLE_CLASS_MOCKING + " to true do modify this behavior");
         }
