@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2020 the original author or authors.
+ * Copyright 2001-2021 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -72,7 +72,7 @@ public class Range implements Serializable {
     }
 
     public String expectedCount() {
-        return "expected: " + this.toString();
+        return "expected: " + this;
     }
 
     public boolean contains(int count) {
