@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2020 the original author or authors.
+ * Copyright 2001-2021 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -97,7 +97,7 @@ public final class Result implements IAnswer<Object>, Serializable {
                 if(!method.isVarArgs()) {
                     return arguments;
                 }
-                Class[] paramTypes = method.getParameterTypes();
+                Class<?>[] paramTypes = method.getParameterTypes();
                 Object[] packedArguments = new Object[paramTypes.length];
 
                 int normalArgLength = paramTypes.length - 1;
