@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2020 the original author or authors.
+ * Copyright 2001-2021 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -28,7 +28,7 @@ public class MockNameTest {
     @Test
     public void defaultName() {
         IMethods mock = createMock(IMethods.class);
-        String expected = "EasyMock for " + IMethods.class.toString();
+        String expected = "EasyMock for " + IMethods.class;
         String actual = mock.toString();
         assertEquals(expected, actual);
     }
