@@ -2,8 +2,6 @@
 
 # This script expects:
 # - gpg_passphrase to be an environment variable
-# - bintray_user to be an environment variable
-# - bintray_api_key to be an environment variable
 
 # to exit in case of error
 set -e
@@ -41,8 +39,6 @@ tag=easymock-${version}
 # Get we have the environment variable we need
 message="should be an environment variable"
 [ -z "$gpg_passphrase" ] && echo "gpg_passphrase $message" && exit 1
-[ -z "$bintray_api_key" ] && echo "bintray_api_key $message" && exit 1
-[ -z "$bintray_user" ] && echo "bintray_user $message" && exit 1
 
 # Seems to be required to make gpg happy
 export GPG_TTY=$(tty)
@@ -80,6 +76,8 @@ mvn clean install -PfullBuild,deployBuild,all
 
 echo "Deploy"
 mvn deploy -PfullBuild,deployBuild,all -DskipTests
+
+echo "Deployment done, please validate the staging repository https://oss.sonatype.org/#stagingRepositories"
 pause
 
 echo "Commit everything"
@@ -111,31 +109,10 @@ echo "\tPublish release"
 open "https://github.com/easymock/easymock/releases"
 pause
 
-# Login to bintray
-echo "Please login on bintray"
-open "https://bintray.com/easymock"
-pause
-
-# Create the distribution in bintray
-date=$(date "+%Y-%m-%d")
-content="{ \"name\": \"$version\", \"desc\": \"$version\", \"released\": \"${date}T00:00:00.000Z\", \"github_use_tag_release_notes\": true, \"vcs_tag\": \"easymock-${version}\" }"
-curl -H "Content-Type: application/json" -u$bintray_user:$bintray_api_key \
-  -d "$content" https://api.bintray.com/packages/easymock/distributions/easymock/versions
-
-curl -v -H "X-GPG-PASSPHRASE: $gpg_passphrase" -u$bintray_user:$bintray_api_key -T "core/target/easymock-${version}-bundle.zip" https://api.bintray.com/content/easymock/distributions/easymock/${version}/easymock-${version}-bundle.zip?publish=1
-
-echo "Flag the bundle as 'Show in download list' in bintray"
-open "https://bintray.com/easymock/distributions/easymock/${version}#files"
-pause
-
 echo "Close the milestone in GitHub and create the new one"
 open "https://github.com/easymock/easymock/milestones"
 pause
 
-echo "Sync to Maven central"
-open "https://bintray.com/easymock/maven/easymock/${version}#central"
-pause
-
 echo "Update Javadoc"
 git rm -rf website/api
 cp -r core/target/apidocs website/api
