@@ -1,5 +1,5 @@
 /*
- * Copyright 2018-2018 the original author or authors.
+ * Copyright 2018-2021 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -52,4 +52,16 @@ public class Java8Test {
         assertEquals(10, mock.normalInterfaceMethod());
         verify(mock);
     }
+
+    @Test
+    public void partialMockOnInterface() {
+        IMethods mock = partialMockBuilder(IMethods.class)
+            .addMockedMethod("defaultInterfaceMethod")
+            .createMock();
+        expect(mock.defaultInterfaceMethod()).andReturn(10);
+        replay(mock);
+        assertEquals(10, mock.defaultInterfaceMethod());
+        verify(mock);
+    }
+
 }
