@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2020 the original author or authors.
+ * Copyright 2015-2021 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -116,8 +116,8 @@ class FilteringClassLoader extends ClassLoader {
 
             out.flush();
 
-            byte bytes[] = out.toByteArray();
-            return bytes == null ? null : defineClass(name, bytes, 0, bytes.length);
+            byte[] bytes = out.toByteArray();
+            return defineClass(name, bytes, 0, bytes.length);
         } finally {
             if (in != null) {
                 in.close();
